summaryrefslogtreecommitdiff
path: root/include/apr_strings.h
diff options
context:
space:
mode:
authorWilliam A. Rowe Jr <wrowe@apache.org>2001-05-16 05:30:52 +0000
committerWilliam A. Rowe Jr <wrowe@apache.org>2001-05-16 05:30:52 +0000
commit5e18b797a4dd06c30e78caa33bbd6991beeef5ed (patch)
tree9b5c141c29ce4f9039ae69d5f41e3df5647d75f3 /include/apr_strings.h
parentf840fae371681fe69a5ec4b74ad1a6e1e7351f58 (diff)
downloadapr-5e18b797a4dd06c30e78caa33bbd6991beeef5ed.tar.gz
Sing, "we are apr"... and make all hash functions accept apr_ssize_t
if we are going to bury -1 flags (I'd prefer the flag cast to apr_size_t and use that value throughout the hash api, however.) git-svn-id: https://svn.apache.org/repos/asf/apr/apr/trunk@61649 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_strings.h')
-rw-r--r--include/apr_strings.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/apr_strings.h b/include/apr_strings.h
index 85d070273..a381855eb 100644
--- a/include/apr_strings.h
+++ b/include/apr_strings.h
@@ -244,9 +244,9 @@ APR_DECLARE(apr_status_t) apr_tokenize_to_argv(const char *arg_str,
* @param len The size of the buffer
* @param format The format string
* @param ... The arguments to use to fill out the format string.
* @deffunc int apr_snprintf(char *buf, size_t len, const char *format, ...)
*/
-APR_DECLARE_NONSTD(int) apr_snprintf(char *buf, size_t len,
+APR_DECLARE_NONSTD(int) apr_snprintf(char *buf, apr_size_t len,
const char *format, ...)
__attribute__((format(printf,3,4)));
@@ -257,9 +257,9 @@ APR_DECLARE_NONSTD(int) apr_snprintf(char *buf, size_t len,
* @param len The size of the buffer
* @param format The format string
* @param ap The arguments to use to fill out the format string.
* @deffunc int apr_vsnprintf(char *buf, size_t len, const char *format, va_list ap)
*/
-APR_DECLARE(int) apr_vsnprintf(char *buf, size_t len, const char *format,
+APR_DECLARE(int) apr_vsnprintf(char *buf, apr_size_t len, const char *format,
va_list ap);
#ifdef __cplusplus
@@ -244,9 +244,9 @@ APR_DECLARE(apr_status_t) apr_tokenize_to_argv(const char *arg_str,
* @param format The format string
* @param ... The arguments to use to fill out the format string.
- * @deffunc int apr_snprintf(char *buf, size_t len, const char *format, ...)
+ * @deffunc int apr_snprintf(char *buf, apr_size_t len, const char *format, ...)
*/
@@ -257,9 +257,9 @@ APR_DECLARE_NONSTD(int) apr_snprintf(char *buf, size_t len,
* @param format The format string
* @param ap The arguments to use to fill out the format string.
- * @deffunc int apr_vsnprintf(char *buf, size_t len, const char *format, va_list ap)
+ * @deffunc int apr_vsnprintf(char *buf, apr_size_t len, const char *format, va_list ap)
*/